pub struct CompensationExecutionReceiptV1 {
pub schema_version: String,
pub compensation_execution_receipt_id: CompensationExecutionReceiptId,
pub compensation_plan_id: CompensationPlanId,
pub citation: V25ConstitutionCitation,
pub execution_state: ExecutionStateV1,
pub completed_steps: Vec<String>,
pub failed_steps: Vec<String>,
pub residual_risk_summary: String,
pub generated_at: String,
}Expand description
Receipt recording the outcome of executing a compensation plan, including completed and failed steps.
Completed receipts must not list any failed steps.
Fields
schema_version: Stringcompensation_execution_receipt_id: CompensationExecutionReceiptIdcompensation_plan_id: CompensationPlanIdcitation: V25ConstitutionCitationCarries EffectiveConstitutionId and CompiledObligationSetId via the canonical v25 citation.
execution_state: ExecutionStateV1completed_steps: Vec<String>failed_steps: Vec<String>residual_risk_summary: Stringgenerated_at: StringImplementations
Sourceimpl CompensationExecutionReceiptV1
impl CompensationExecutionReceiptV1
pub const SCHEMA_VERSION: &'static str = "CompensationExecutionReceiptV1"
Sourcepub fn builder(
compensation_execution_receipt_id: CompensationExecutionReceiptId,
compensation_plan_id: CompensationPlanId,
citation: V25ConstitutionCitation,
execution_state: ExecutionStateV1,
completed_steps: Vec<String>,
failed_steps: Vec<String>,
residual_risk_summary: impl Into<String>,
generated_at: impl Into<String>,
) -> CompensationExecutionReceiptV1Builder
pub fn builder( compensation_execution_receipt_id: CompensationExecutionReceiptId, compensation_plan_id: CompensationPlanId, citation: V25ConstitutionCitation, execution_state: ExecutionStateV1, completed_steps: Vec<String>, failed_steps: Vec<String>, residual_risk_summary: impl Into<String>, generated_at: impl Into<String>, ) -> CompensationExecutionReceiptV1Builder
Returns a builder for a validated compensation execution receipt artifact.
Sourcepub fn validate(&self) -> EffectValidationResult
pub fn validate(&self) -> EffectValidationResult
Validates the owner-side invariants for a compensation execution receipt.