pub struct CompensationPlanV1 {
pub schema_version: String,
pub compensation_plan_id: CompensationPlanId,
pub effect_intent_id: EffectIntentId,
pub citation: V25ConstitutionCitation,
pub compensation_required: bool,
pub compensation_class: CompensationClassV1,
pub compensation_steps: Vec<String>,
pub success_criteria: Vec<String>,
pub owner_ref: String,
pub latest_start: String,
pub advisory_only: bool,
}Expand description
Plan describing the compensation steps required to reverse or mitigate a failed effect.
When compensation_required is true, compensation_steps must be non-empty.
Fields
schema_version: Stringcompensation_plan_id: CompensationPlanIdeffect_intent_id: EffectIntentIdcitation: V25ConstitutionCitationCarries EffectiveConstitutionId and CompiledObligationSetId via the canonical v25 citation.
compensation_required: boolcompensation_class: CompensationClassV1compensation_steps: Vec<String>success_criteria: Vec<String>owner_ref: Stringlatest_start: Stringadvisory_only: boolImplementations
Sourceimpl CompensationPlanV1
impl CompensationPlanV1
pub const SCHEMA_VERSION: &'static str = "CompensationPlanV1"
Sourcepub fn builder(
compensation_plan_id: CompensationPlanId,
effect_intent_id: EffectIntentId,
citation: V25ConstitutionCitation,
compensation_required: bool,
compensation_class: CompensationClassV1,
compensation_steps: Vec<String>,
success_criteria: Vec<String>,
owner_ref: impl Into<String>,
latest_start: impl Into<String>,
advisory_only: bool,
) -> CompensationPlanV1Builder
pub fn builder( compensation_plan_id: CompensationPlanId, effect_intent_id: EffectIntentId, citation: V25ConstitutionCitation, compensation_required: bool, compensation_class: CompensationClassV1, compensation_steps: Vec<String>, success_criteria: Vec<String>, owner_ref: impl Into<String>, latest_start: impl Into<String>, advisory_only: bool, ) -> CompensationPlanV1Builder
Returns a builder for a validated compensation plan artifact.
Sourcepub fn validate(&self) -> EffectValidationResult
pub fn validate(&self) -> EffectValidationResult
Validates the owner-side invariants for a compensation plan.