EffectPreflightReportV1

Struct EffectPreflightReportV1 

pub struct EffectPreflightReportV1 {
    pub schema_version: String,
    pub effect_preflight_report_id: EffectPreflightReportId,
    pub effect_intent_id: EffectIntentId,
    pub citation: V25ConstitutionCitation,
    pub obligation_refs: V25ObligationRefs,
    pub input_integrity_result: CheckResultV1,
    pub admission_check_result: CheckResultV1,
    pub dependency_reachability_result: CheckResultV1,
    pub budget_sufficiency_result: BudgetSufficiencyResultV1,
    pub disposition: EffectPreflightDispositionV1,
    pub generated_at: String,
    pub notes: Vec<String>,
}
Result of preflight checks against an effect intent, gating commit eligibility.

A CommitEligible disposition requires all check results to be passing and budget to be sufficient.

Fields

schema_version: Stringeffect_preflight_report_id: EffectPreflightReportIdeffect_intent_id: EffectIntentIdcitation: V25ConstitutionCitation

Carries ApplicabilityContextId, ProfileSetId, CompositionReceiptId, EffectiveConstitutionId, CompiledObligationSetId, and ProfileExceptionBundleId.

obligation_refs: V25ObligationRefsinput_integrity_result: CheckResultV1admission_check_result: CheckResultV1dependency_reachability_result: CheckResultV1budget_sufficiency_result: BudgetSufficiencyResultV1disposition: EffectPreflightDispositionV1generated_at: Stringnotes: Vec<String>

Implementations

Source

impl EffectPreflightReportV1

pub const SCHEMA_VERSION: &'static str = "EffectPreflightReportV1"

pub fn builder( effect_preflight_report_id: EffectPreflightReportId, effect_intent_id: EffectIntentId, citation: V25ConstitutionCitation, obligation_refs: V25ObligationRefs, input_integrity_result: CheckResultV1, admission_check_result: CheckResultV1, dependency_reachability_result: CheckResultV1, budget_sufficiency_result: BudgetSufficiencyResultV1, disposition: EffectPreflightDispositionV1, generated_at: impl Into<String>, notes: Vec<String>, ) -> EffectPreflightReportV1Builder

Returns a builder for a validated preflight report artifact.

pub fn validate(&self) -> EffectValidationResult

Validates the owner-side invariants for a preflight report.