pub struct EffectWindowV1 {
pub schema_version: String,
pub effect_window_id: EffectWindowId,
pub earliest_start: String,
pub latest_admissible_start: String,
pub timeout_at: String,
pub commit_atomicity: CommitAtomicityV1,
pub retry_owner: RetryOwnerV1,
pub close_midflight_behavior: CloseMidflightBehaviorV1,
}Expand description
Temporal execution window that bounds when an effect may start, timeout, and how mid-flight closures are handled.
Fields
schema_version: Stringeffect_window_id: EffectWindowIdearliest_start: Stringlatest_admissible_start: Stringtimeout_at: Stringcommit_atomicity: CommitAtomicityV1retry_owner: RetryOwnerV1close_midflight_behavior: CloseMidflightBehaviorV1Implementations
Sourceimpl EffectWindowV1
impl EffectWindowV1
pub const SCHEMA_VERSION: &'static str = "EffectWindowV1"
Sourcepub fn builder(
effect_window_id: EffectWindowId,
earliest_start: impl Into<String>,
latest_admissible_start: impl Into<String>,
timeout_at: impl Into<String>,
commit_atomicity: CommitAtomicityV1,
retry_owner: RetryOwnerV1,
close_midflight_behavior: CloseMidflightBehaviorV1,
) -> EffectWindowV1Builder
pub fn builder( effect_window_id: EffectWindowId, earliest_start: impl Into<String>, latest_admissible_start: impl Into<String>, timeout_at: impl Into<String>, commit_atomicity: CommitAtomicityV1, retry_owner: RetryOwnerV1, close_midflight_behavior: CloseMidflightBehaviorV1, ) -> EffectWindowV1Builder
Returns a builder for a validated execution window artifact.
Sourcepub fn validate(&self) -> EffectValidationResult
pub fn validate(&self) -> EffectValidationResult
Validates the owner-side invariants for an execution window.