pub struct ExternalEffectLedgerEntryV1 {
pub schema_version: String,
pub external_effect_ledger_entry_id: ExternalEffectLedgerEntryId,
pub effect_execution_receipt_id: EffectExecutionReceiptId,
pub citation: V25ConstitutionCitation,
pub target_system: String,
pub external_handle: String,
pub externally_observed_state: ExternalObservationStateV1,
pub entered_at: String,
pub immutable: bool,
}Expand description
Ledger entry recording an effect’s side-effect in an external system for audit and reconciliation.
Fields
schema_version: Stringexternal_effect_ledger_entry_id: ExternalEffectLedgerEntryIdeffect_execution_receipt_id: EffectExecutionReceiptIdcitation: V25ConstitutionCitationCarries EffectiveConstitutionId and CompiledObligationSetId via the canonical v25 citation.
target_system: Stringexternal_handle: Stringexternally_observed_state: ExternalObservationStateV1entered_at: Stringimmutable: boolImplementations
Sourceimpl ExternalEffectLedgerEntryV1
impl ExternalEffectLedgerEntryV1
pub const SCHEMA_VERSION: &'static str = "ExternalEffectLedgerEntryV1"
Sourcepub fn builder(
external_effect_ledger_entry_id: ExternalEffectLedgerEntryId,
effect_execution_receipt_id: EffectExecutionReceiptId,
citation: V25ConstitutionCitation,
target_system: impl Into<String>,
external_handle: impl Into<String>,
externally_observed_state: ExternalObservationStateV1,
entered_at: impl Into<String>,
immutable: bool,
) -> ExternalEffectLedgerEntryV1Builder
pub fn builder( external_effect_ledger_entry_id: ExternalEffectLedgerEntryId, effect_execution_receipt_id: EffectExecutionReceiptId, citation: V25ConstitutionCitation, target_system: impl Into<String>, external_handle: impl Into<String>, externally_observed_state: ExternalObservationStateV1, entered_at: impl Into<String>, immutable: bool, ) -> ExternalEffectLedgerEntryV1Builder
Returns a builder for a validated external ledger entry artifact.
Sourcepub fn validate(&self) -> EffectValidationResult
pub fn validate(&self) -> EffectValidationResult
Validates the owner-side invariants for an external ledger entry.