pub struct V25ObligationRefs {
pub required_obligation_refs: Vec<String>,
pub blocking_obligation_refs: Vec<String>,
pub monitoring_obligation_refs: Vec<String>,
pub decision_basis_obligation_refs: Vec<String>,
}Expand description
Categorized obligation references attached to effect artifacts for governance traceability.
Flattened into parent structs via #[serde(flatten)] to keep the wire
format flat while grouping obligation ref categories in code.
Fields
required_obligation_refs: Vec<String>blocking_obligation_refs: Vec<String>monitoring_obligation_refs: Vec<String>decision_basis_obligation_refs: Vec<String>Trait Implementations
Sourceimpl Clone for V25ObligationRefs
impl Clone for V25ObligationRefs
Sourcefn clone(&self) -> V25ObligationRefs
fn clone(&self) -> V25ObligationRefs
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for V25ObligationRefs
impl Debug for V25ObligationRefs
Sourceimpl<'de> Deserialize<'de> for V25ObligationRefs
impl<'de> Deserialize<'de> for V25ObligationRefs
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for V25ObligationRefs
Sourceimpl JsonSchema for V25ObligationRefs
impl JsonSchema for V25ObligationRefs
Sourcefn schema_name() -> String
fn schema_name() -> String
The name of the generated JSON Schema. Read more
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn is_referenceable() -> bool
fn is_referenceable() -> bool
Whether JSON Schemas generated for this type should be re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for V25ObligationRefs
impl PartialEq for V25ObligationRefs
Sourcefn eq(&self, other: &V25ObligationRefs) -> bool
fn eq(&self, other: &V25ObligationRefs) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for V25ObligationRefs
impl Serialize for V25ObligationRefs
impl StructuralPartialEq for V25ObligationRefs