pub struct EffectCommitDecisionV1 {Show 13 fields
pub schema_version: String,
pub effect_commit_decision_id: EffectCommitDecisionId,
pub effect_intent_id: EffectIntentId,
pub effect_preflight_report_id: EffectPreflightReportId,
pub citation: V25ConstitutionCitation,
pub obligation_refs: V25ObligationRefs,
pub approval_obligation_refs: Vec<String>,
pub decision_state: EffectCommitDispositionV1,
pub approver_refs: Vec<String>,
pub execution_permit_id: Option<ExecutionPermitId>,
pub approval_grant_id: Option<ApprovalGrantId>,
pub refusal_reason: String,
pub generated_at: String,
}Expand description
Authorization decision for committing an effect, linking intent and preflight report to an execution permit.
Authorized decisions must carry an execution permit and approver refs. Denied decisions must carry a refusal reason and must not mint permits.
Fields
schema_version: Stringeffect_commit_decision_id: EffectCommitDecisionIdeffect_intent_id: EffectIntentIdeffect_preflight_report_id: EffectPreflightReportIdcitation: V25ConstitutionCitationCarries ApplicabilityContextId, ProfileSetId, CompositionReceiptId, EffectiveConstitutionId, CompiledObligationSetId, and ProfileExceptionBundleId.
obligation_refs: V25ObligationRefsapproval_obligation_refs: Vec<String>decision_state: EffectCommitDispositionV1approver_refs: Vec<String>execution_permit_id: Option<ExecutionPermitId>approval_grant_id: Option<ApprovalGrantId>refusal_reason: Stringgenerated_at: StringImplementations
Sourceimpl EffectCommitDecisionV1
impl EffectCommitDecisionV1
pub const SCHEMA_VERSION: &'static str = "EffectCommitDecisionV1"
Sourcepub fn builder(
effect_commit_decision_id: EffectCommitDecisionId,
effect_intent_id: EffectIntentId,
effect_preflight_report_id: EffectPreflightReportId,
citation: V25ConstitutionCitation,
obligation_refs: V25ObligationRefs,
approval_obligation_refs: Vec<String>,
decision_state: EffectCommitDispositionV1,
approver_refs: Vec<String>,
execution_permit_id: Option<ExecutionPermitId>,
approval_grant_id: Option<ApprovalGrantId>,
refusal_reason: impl Into<String>,
generated_at: impl Into<String>,
) -> EffectCommitDecisionV1Builder
pub fn builder( effect_commit_decision_id: EffectCommitDecisionId, effect_intent_id: EffectIntentId, effect_preflight_report_id: EffectPreflightReportId, citation: V25ConstitutionCitation, obligation_refs: V25ObligationRefs, approval_obligation_refs: Vec<String>, decision_state: EffectCommitDispositionV1, approver_refs: Vec<String>, execution_permit_id: Option<ExecutionPermitId>, approval_grant_id: Option<ApprovalGrantId>, refusal_reason: impl Into<String>, generated_at: impl Into<String>, ) -> EffectCommitDecisionV1Builder
Returns a builder for a validated commit decision artifact.
Sourcepub fn validate(&self) -> EffectValidationResult
pub fn validate(&self) -> EffectValidationResult
Validates the owner-side invariants for a commit decision.