pub struct EffectIntentV1 {Show 16 fields
pub schema_version: String,
pub effect_intent_id: EffectIntentId,
pub effect_class: EffectClassV1,
pub target_surface: String,
pub intended_outcome: String,
pub initiating_artifact_refs: Vec<String>,
pub required_capability_class: String,
pub allowed_scope: String,
pub blast_radius_ceiling: BlastRadiusCeilingV1,
pub reversibility_class: ReversibilityClassV1,
pub idempotency_key: String,
pub execution_window_id: EffectWindowId,
pub observability_obligation_refs: Vec<String>,
pub approval_refs: Vec<String>,
pub run_mode: RunModeV1,
pub publication_status: PublicationStatusV1,
}Expand description
Declaration of an intended effect including its class, target surface, blast radius, and approval requirements.
This is the entry point of the effect lifecycle. Live-mode intents require non-empty approval refs before they can proceed to preflight.
Fields
schema_version: Stringeffect_intent_id: EffectIntentIdeffect_class: EffectClassV1target_surface: Stringintended_outcome: Stringinitiating_artifact_refs: Vec<String>required_capability_class: Stringallowed_scope: Stringblast_radius_ceiling: BlastRadiusCeilingV1reversibility_class: ReversibilityClassV1idempotency_key: Stringexecution_window_id: EffectWindowIdobservability_obligation_refs: Vec<String>approval_refs: Vec<String>run_mode: RunModeV1publication_status: PublicationStatusV1Implementations
Sourceimpl EffectIntentV1
impl EffectIntentV1
pub const SCHEMA_VERSION: &'static str = "EffectIntentV1"
Sourcepub fn builder(
effect_intent_id: EffectIntentId,
effect_class: EffectClassV1,
target_surface: impl Into<String>,
intended_outcome: impl Into<String>,
initiating_artifact_refs: Vec<String>,
required_capability_class: impl Into<String>,
allowed_scope: impl Into<String>,
blast_radius_ceiling: BlastRadiusCeilingV1,
reversibility_class: ReversibilityClassV1,
idempotency_key: impl Into<String>,
execution_window_id: EffectWindowId,
observability_obligation_refs: Vec<String>,
approval_refs: Vec<String>,
run_mode: RunModeV1,
publication_status: PublicationStatusV1,
) -> EffectIntentV1Builder
pub fn builder( effect_intent_id: EffectIntentId, effect_class: EffectClassV1, target_surface: impl Into<String>, intended_outcome: impl Into<String>, initiating_artifact_refs: Vec<String>, required_capability_class: impl Into<String>, allowed_scope: impl Into<String>, blast_radius_ceiling: BlastRadiusCeilingV1, reversibility_class: ReversibilityClassV1, idempotency_key: impl Into<String>, execution_window_id: EffectWindowId, observability_obligation_refs: Vec<String>, approval_refs: Vec<String>, run_mode: RunModeV1, publication_status: PublicationStatusV1, ) -> EffectIntentV1Builder
Returns a builder for a validated effect intent artifact.
Sourcepub fn validate(&self) -> EffectValidationResult
pub fn validate(&self) -> EffectValidationResult
Validates the owner-side invariants for an effect intent.